@@ -39,13 +39,13 @@ normalizer_nfc <- R6::R6Class(
 #' @export
 #' @family normalizers
 normalizer_nfkc <- R6::R6Class(
-  "tok_normalizer_nfc",
+  "tok_normalizer_nfkc",
   inherit = tok_normalizer,
   public = list(
     #' @description
     #' Initializes the NFKC normalizer
     initialize = function() {
-      super$initialize(RNormalizerNFC$new())
+      super$initialize(RNormalizerNFKC$new())
     }  
   )
 )
