@@ -1,22 +1,20 @@
 use extendr_api::prelude::*;
 use tokenizers as tk;
 
+#[extendr]
 pub struct RDecoder(pub tk::DecoderWrapper);
 
 #[extendr]
 impl RDecoder {
     pub fn new(decoder: Robj) -> extendr_api::Result<Self> {
         if decoder.inherits("RDecoderByteLevel") {
-            unsafe {
-                let ptr = decoder.external_ptr_addr() as *mut RDecoderByteLevel;
-                Ok(RDecoder((*ptr).0.clone().into()))
-            }
+            Ok(RDecoder(<&RDecoderByteLevel>::try_from(&decoder)?.0.clone().into()))
         } else {
             Err(Error::EvalError("Unsupported decoder".into()))
         }
     }
 }
-
+#[extendr]
 struct RDecoderByteLevel(tk::decoders::byte_level::ByteLevel);
 
 #[extendr]
