@@ -5,6 +5,5 @@ files <- list.files(
   full.names = TRUE, 
   include.dirs = FALSE
 )
-for (f in files) {
-  write("\n", file = f, append = TRUE)
-}
\ No newline at end of file
+
+file.remove(files)
\ No newline at end of file
